SELECT
  field_1
  , field_2
  , field_3
  , time
  , date
  , timestamp
FROM my_table;
